@@ -1,10 +1,10 @@
 package Stepford;
-# git description: v0.003002-3-g5aec001
-$Stepford::VERSION = '0.003003';
 
 use strict;
 use warnings;
 
+our $VERSION = '0.003004';
+
 1;
 
 # ABSTRACT: A vaguely Rake/Make/Cake-like thing for Perl - create steps and let a runner run them
@@ -19,7 +19,7 @@ Stepford - A vaguely Rake/Make/Cake-like thing for Perl - create steps and let a
 
 =head1 VERSION
 
-version 0.003003
+version 0.003004
 
 =head1 SYNOPSIS
 
@@ -80,8 +80,23 @@ actual implementation is fairly different. Currently, there is no DSL, no
 Stepfile, etc.
 
 With Stepford, each step is represented by a class you create. That class
-should consume either the L<Stepford::Role::Step::FileGenerator> role (if it
-generates files) or the L<Stepford::Role::Step> step (if it doesn't).
+should consume one of the available Step roles. Those are:
+
+=over 4
+
+=item * L<Stepford::Role::Step::FileGenerator>
+
+For steps that generate files.
+
+=item * L<Stepford::Role::Step>
+
+For steps that I<don't> generate files.
+
+=item * L<Stepford::Role::Step::FileGenerator>
+
+For a step that wants to generate a single file atomically.
+
+=back
 
 Steps declare both their dependencies (required inputs) and productions
 (outputs) as attributes. These attributes should be given either the
@@ -96,7 +111,8 @@ L<Stepford::Role::Step::FileGenerator> role). The runner uses this to skip
 steps that are up to date.
 
 See L<Stepford::Runner>, L<Stepford::Role::Step>, and
-L<Stepford::Role::Step::FileGenerator> for more details.
+L<Stepford::Role::Step::FileGenerator>, and
+L<Stepford::Role::Step::FileGenerator::Atomic> for more details.
 
 =for test_synopsis my $log_object;
 
@@ -186,7 +202,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Greg Oschwald Olaf Alders Ran Eilam
+=for stopwords Greg Oschwald Mark Fowler Olaf Alders Ran Eilam
 
 =over 4
 
@@ -196,6 +212,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =item *
