@@ -1,7 +1,10 @@
 package Stepford::Error;
-$Stepford::Error::VERSION = '0.003003';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.003004';
 
 use Moose;
 
@@ -23,7 +26,7 @@ Stepford::Error - A Stepford exception object
 
 =head1 VERSION
 
-version 0.003003
+version 0.003004
 
 =head1 DESCRIPTION
 
