@@ -1,7 +1,10 @@
 package Stepford::LoggerWithMoniker;
-$Stepford::LoggerWithMoniker::VERSION = '0.003003';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.003004';
 
 use Stepford::Types qw( Logger Str );
 
@@ -50,7 +53,7 @@ Stepford::LoggerWithMoniker - The logger used by Step classes.
 
 =head1 VERSION
 
-version 0.003003
+version 0.003004
 
 =head1 DESCRIPTION
 
