@@ -1,7 +1,10 @@
 package Stepford::Planner;
-$Stepford::Planner::VERSION = '0.003003';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.003004';
 
 use Carp qw( carp );
 
@@ -10,16 +13,20 @@ use Moose;
 extends 'Stepford::Runner';
 
 override new => sub {
+
     # Needed to escape modifier caller.
+    ## no critic (Variables::ProhibitPackageVars)
     local $Carp::CarpLevel = $Carp::CarpLevel + 1;
     carp
         'The Stepford::Planner class has been renamed to Stepford::Runner - use Stepford::Runner';
     return super();
 };
 
+__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
+
 1;
 
-# ABSTRACT: Renamed to Stepford;:Runner
+# ABSTRACT: Renamed to Stepford::Runner
 
 __END__
 
@@ -27,11 +34,11 @@ __END__
 
 =head1 NAME
 
-Stepford::Planner - Renamed to Stepford;:Runner
+Stepford::Planner - Renamed to Stepford::Runner
 
 =head1 VERSION
 
-version 0.003003
+version 0.003004
 
 =head1 DESCRIPTION
 
